import logging
import mmmanage.util as util

def grant_monitor(config, ip):
    monitor = config.get('monitoring')
    user = monitor['user']
    password = monitor['password']
    db = monitor['db']

    logging.info(f"Setting monitoring grants for {ip}...")
    (exit, stdout, stderr) = util.local(["mysql", "-e", f"CREATE USER IF NOT EXISTS '{user}'@'{ip}' IDENTIFIED BY '{password}';"])
    if exit != 0:
        raise Exception("Failed to create monitoring user!")

    (exit, stdout, stderr) = util.local(["mysql", "-e", f"GRANT ALL PRIVILEGES ON {db}.* to '{user}'@'{ip}';"])
    if exit != 0:
        raise Exception("Failed to grant monitoring DB permissions!")


    # mariadb
    permstring = f"GRANT REPLICATION SLAVE,REPLICATION CLIENT,PROCESS,SLAVE MONITOR,REPLICATION MASTER ADMIN  ON *.* TO '{user}'@'{ip}';"

    # mysql / percona
    if 'db_version' in config and config.get('db_version') == "percona8":
        logging.info(f"Using MySQL8 / Percona grant")
        permstring = f"GRANT REPLICATION SLAVE,REPLICATION CLIENT,PROCESS  ON *.* TO '{user}'@'{ip}';"

    (exit, stdout, stderr) = util.local(["mysql", "-e", permstring])
    if exit != 0:
        raise Exception("Failed to grant monitoring permissions!")


def write_monitor(config, check):
    config_file = "/etc/mythic/mysql-check.yaml"
    if check:
        logging.info(f"Would write monitoring config file")
    else:
        logging.info(f"Writing monitoring config file {config_file}")
        monitor = config.get('monitoring')
        user = monitor['user']
        password = monitor['password']
        db = monitor['db']

        content = ["---", f"username: {user}", f"password: {password}", f"database: {db}","hosts:\n"]
    
        replicas = config.get('replicas')
        me = config.get('me')

        f = open(config_file, "w")
        f.write("\n".join(content))

        ip = me['ip']
        f.write(f" - {ip}\n")
        for r in replicas:
            ip = r['ip']
            f.write(f" - {ip}\n")
        f.close()

    